@@ -253,5 +253,141 @@ pub fn ch<'pokemon_ch>() -> Vec<&'pokemon_ch str> {
         "洛奇亞",
         "鳳王",
         "時拉比",
+        // GEN 3
+        "木守宮",
+        "森林蜥蜴",
+        "蜥蜴王",
+        "火稚雞",
+        "力壯雞",
+        "火焰雞",
+        "水躍魚",
+        "沼躍魚",
+        "巨沼怪",
+        "土狼犬",
+        "大狼犬",
+        "蛇紋熊",
+        "直衝熊",
+        "刺尾蟲",
+        "甲殼繭",
+        "狩獵鳳蝶",
+        "盾甲繭",
+        "毒粉蛾",
+        "蓮葉童子",
+        "蓮帽小童",
+        "樂天河童",
+        "橡實果",
+        "長鼻葉",
+        "狡猾天狗",
+        "傲骨燕",
+        "大王燕",
+        "長翅鷗",
+        "大嘴鷗",
+        "拉魯拉絲",
+        "奇魯莉安",
+        "沙奈朵",
+        "溜溜糖球",
+        "雨翅蛾",
+        "蘑蘑菇",
+        "斗笠菇",
+        "懶人獺",
+        "過動猿",
+        "請假王",
+        "土居忍士",
+        "鐵面忍者",
+        "脫殼忍者",
+        "咕妞妞",
+        "吼爆彈",
+        "爆音怪",
+        "幕下力士",
+        "鐵掌力士",
+        "露力麗",
+        "朝北鼻",
+        "向尾喵",
+        "優雅貓",
+        "勾魂眼",
+        "大嘴娃",
+        "可可多拉",
+        "可多拉",
+        "波士可多拉",
+        "瑪沙那",
+        "恰雷姆",
+        "落雷獸",
+        "雷電獸",
+        "正電拍拍",
+        "負電拍拍",
+        "電螢蟲",
+        "甜甜螢",
+        "毒薔薇",
+        "溶食獸",
+        "吞食獸",
+        "利牙魚",
+        "巨牙鯊",
+        "吼吼鯨",
+        "吼鯨王",
+        "呆火駝",
+        "噴火駝",
+        "煤炭龜",
+        "跳跳豬",
+        "噗噗豬",
+        "晃晃斑",
+        "大顎蟻",
+        "超音波幼蟲",
+        "沙漠蜻蜓",
+        "刺球仙人掌",
+        "夢歌仙人掌",
+        "青綿鳥",
+        "七夕青鳥",
+        "貓鼬斬",
+        "飯匙蛇",
+        "月石",
+        "太陽岩",
+        "泥泥鰍",
+        "鯰魚王",
+        "龍蝦小兵",
+        "鐵螯龍蝦",
+        "天秤偶",
+        "念力土偶",
+        "觸手百合",
+        "搖籃百合",
+        "太古羽蟲",
+        "太古盔甲",
+        "醜醜魚",
+        "美納斯",
+        "飄浮泡泡",
+        "變隱龍",
+        "怨影娃娃",
+        "詛咒娃娃",
+        "夜巡靈",
+        "彷徨夜靈",
+        "熱帶龍",
+        "風鈴鈴",
+        "阿勃梭魯",
+        "小果然",
+        "雪童子",
+        "冰鬼護",
+        "海豹球",
+        "海魔獅",
+        "帝牙海獅",
+        "珍珠貝",
+        "獵斑魚",
+        "櫻花魚",
+        "古空棘魚",
+        "愛心魚",
+        "寶貝龍",
+        "甲殼龍",
+        "暴飛龍",
+        "鐵啞鈴",
+        "金屬怪",
+        "巨金怪",
+        "雷吉洛克",
+        "雷吉艾斯",
+        "雷吉斯奇魯",
+        "拉帝亞斯",
+        "拉帝歐斯",
+        "蓋歐卡",
+        "固拉多",
+        "烈空坐",
+        "基拉祈",
+        "代歐奇希斯"
     ]
 }
