@@ -253,5 +253,141 @@ pub fn de<'pokemon_de>() -> Vec<&'pokemon_de str> {
         "Lugia",
         "Ho-Oh",
         "Celebi",
+        // GEN 3
+        "Geckarbor",
+        "Reptain",
+        "Gewaldro",
+        "Flemmli",
+        "Jungglut",
+        "Lohgock",
+        "Hydropi",
+        "Moorabbel",
+        "Sumpex",
+        "Fiffyen",
+        "Magnayen",
+        "Zigzachs",
+        "Geradaks",
+        "Waumpel",
+        "Schaloko",
+        "Papinella",
+        "Panekon",
+        "Pudox",
+        "Loturzel",
+        "Lombrero",
+        "Kappalores",
+        "Samurzel",
+        "Blanas",
+        "Tengulist",
+        "Schwalbini",
+        "Schwalboss",
+        "Wingull",
+        "Pelipper",
+        "Trasla",
+        "Kirlia",
+        "Guardevoir",
+        "Gehweiher",
+        "Maskeregen",
+        "Knilz",
+        "Kapilz",
+        "Bummelz",
+        "Muntier",
+        "Letarking",
+        "Nincada",
+        "Ninjask",
+        "Ninjatom",
+        "Flurmel",
+        "Krakeelo",
+        "Krawumms",
+        "Makuhita",
+        "Hariyama",
+        "Azurill",
+        "Nasgnet",
+        "Eneco",
+        "Enekoro",
+        "Zobiris",
+        "Flunkifer",
+        "Stollunior",
+        "Stollrak",
+        "Stolloss",
+        "Meditie",
+        "Meditalis",
+        "Frizelbliz",
+        "Voltenso",
+        "Plusle",
+        "Minun",
+        "Volbeat",
+        "Illumise",
+        "Roselia",
+        "Schluppuck",
+        "Schlukwech",
+        "Kanivanha",
+        "Tohaido",
+        "Wailmer",
+        "Wailord",
+        "Camaub",
+        "Camerupt",
+        "Qurtel",
+        "Spoink",
+        "Groink",
+        "Pandir",
+        "Knacklion",
+        "Vibrava",
+        "Libelldra",
+        "Tuska",
+        "Noktuska",
+        "Wablu",
+        "Altaria",
+        "Sengo",
+        "Vipitis",
+        "Lunastein",
+        "Sonnfel",
+        "Schmerbe",
+        "Welsar",
+        "Krebscorps",
+        "Krebutack",
+        "Puppance",
+        "Lepumentas",
+        "Liliep",
+        "Wielie",
+        "Anorith",
+        "Armaldo",
+        "Barschwa",
+        "Milotic",
+        "Formeo",
+        "Kecleon",
+        "Shuppet",
+        "Banette",
+        "Zwirrlicht",
+        "Zwirrklop",
+        "Tropius",
+        "Palimpalim",
+        "Absol",
+        "Isso",
+        "Schneppke",
+        "Firnontor",
+        "Seemops",
+        "Seejong",
+        "Walraisa",
+        "Perlu",
+        "Aalabyss",
+        "Saganabyss",
+        "Relicanth",
+        "Liebiskus",
+        "Kindwurm",
+        "Draschel",
+        "Brutalanda",
+        "Tanhel",
+        "Metang",
+        "Metagross",
+        "Regirock",
+        "Regice",
+        "Registeel",
+        "Latias",
+        "Latios",
+        "Kyogre",
+        "Groudon",
+        "Rayquaza",
+        "Jirachi",
+        "Deoxys"
     ]
 }
