@@ -253,5 +253,141 @@ pub fn fr<'pokemon_fr>() -> Vec<&'pokemon_fr str> {
         "Lugia",
         "Ho-Oh",
         "Celebi",
+        // GEN 3
+        "Arcko",
+        "Massko",
+        "Jungko",
+        "Poussifeu",
+        "Galifeu",
+        "Braségali",
+        "Gobou",
+        "Flobio",
+        "Laggron",
+        "Medhyèna",
+        "Grahyèna",
+        "Zigzaton",
+        "Linéon",
+        "Chenipotte",
+        "Armulys",
+        "Charmillon",
+        "Blindalys",
+        "Papinox",
+        "Nénupiot",
+        "Lombre",
+        "Ludicolo",
+        "Grainipiot",
+        "Pifeuil",
+        "Tengalice",
+        "Nirondelle",
+        "Hélédelle",
+        "Goélise",
+        "Bekipan",
+        "Tarsal",
+        "Kirlia",
+        "Gardevoir",
+        "Arakdo",
+        "Maskadra",
+        "Balignon",
+        "Chapignon",
+        "Parecool",
+        "Vigoroth",
+        "Monaflèmit",
+        "Ningale",
+        "Ninjask",
+        "Munja",
+        "Chuchmur",
+        "Ramboum",
+        "Brouhabam",
+        "Makuhita",
+        "Hariyama",
+        "Azurill",
+        "Tarinor",
+        "Skitty",
+        "Delcatty",
+        "Ténéfix",
+        "Mysdibule",
+        "Galekid",
+        "Galegon",
+        "Galeking",
+        "Méditikka",
+        "Charmina",
+        "Dynavolt",
+        "Élecsprint",
+        "Posipi",
+        "Négapi",
+        "Muciole",
+        "Lumivole",
+        "Rosélia",
+        "Gloupti",
+        "Avaltout",
+        "Carvanha",
+        "Sharpedo",
+        "Wailmer",
+        "Wailord",
+        "Chamallot",
+        "Camérupt",
+        "Chartor",
+        "Spoink",
+        "Groret",
+        "Spinda",
+        "Kraknoix",
+        "Vibraninf",
+        "Libégon",
+        "Cacnea",
+        "Cacturne",
+        "Tylton",
+        "Altaria",
+        "Mangriff",
+        "Séviper",
+        "Séléroc",
+        "Solaroc",
+        "Barloche",
+        "Barbicha",
+        "Écrapince",
+        "Colhomard",
+        "Balbuto",
+        "Kaorine",
+        "Lilia",
+        "Vacilys",
+        "Anorith",
+        "Armaldo",
+        "Barpau",
+        "Milobellus",
+        "Morphéo",
+        "Kecleon",
+        "Polichombr",
+        "Branette",
+        "Skelénox",
+        "Téraclope",
+        "Tropius",
+        "Éoko",
+        "Absol",
+        "Okéoké",
+        "Stalgamin",
+        "Oniglali",
+        "Obalie",
+        "Phogleur",
+        "Kaimorse",
+        "Coquiperl",
+        "Serpang",
+        "Rosabyss",
+        "Relicanth",
+        "Lovdisc",
+        "Draby",
+        "Drackhaus",
+        "Drattak",
+        "Terhal",
+        "Métang",
+        "Métalosse",
+        "Regirock",
+        "Regice",
+        "Registeel",
+        "Latias",
+        "Latios",
+        "Kyogre",
+        "Groudon",
+        "Rayquaza",
+        "Jirachi",
+        "Deoxys",
     ]
 }
