@@ -253,5 +253,141 @@ pub fn ru<'pokemon_ru>() -> Vec<&'pokemon_ru str> {
         "Люджия",
         "Хо-Ох",
         "Целеби",
+        // GEN 3
+        "Трико",
+        "Гроувайл",
+        "Скептайл",
+        "Торчик",
+        "Комбускен",
+        "Блейзикен",
+        "Мадкип",
+        "Марштомп",
+        "Свамперт",
+        "Пучиена",
+        "Майтиена",
+        "Зигзагун",
+        "Лайнун",
+        "Вёрмпл",
+        "Силкун",
+        "Бьютифлай",
+        "Каскун",
+        "Дастокс",
+        "Лотад",
+        "Ломбре",
+        "Лудиколо",
+        "Сидот",
+        "Назлиф",
+        "Шифтри",
+        "Тейлоу",
+        "Свеллоу",
+        "Вингалл",
+        "Пелиппер",
+        "Ральтс",
+        "Кирлия",
+        "Гардевуар",
+        "Сёрскит",
+        "Маскверейн",
+        "Шрумиш",
+        "Брелум",
+        "Слэйкот",
+        "Вигорот",
+        "Слэйкинг",
+        "Нинкада",
+        "Нинджаск",
+        "Шединджа",
+        "Висмур",
+        "Лаудред",
+        "Эксплауд",
+        "Макухита",
+        "Харияма",
+        "Азурилл",
+        "Ноуспасс",
+        "Скитти",
+        "Делкатти",
+        "Саблай",
+        "Мэвайл",
+        "Арон",
+        "Лейрон",
+        "Аггрон",
+        "Медитайт",
+        "Медичам",
+        "Электрайк",
+        "Манектрик",
+        "Плюсл",
+        "Минун",
+        "Волбит",
+        "Иллюмизи",
+        "Розалия",
+        "Галпин",
+        "Свалот",
+        "Карванна",
+        "Шарпидо",
+        "Вэйлмер",
+        "Вэйлорд",
+        "Намел",
+        "Камерапт",
+        "Торкл",
+        "Споинк",
+        "Грампиг",
+        "Спинда",
+        "Трапинч",
+        "Вибрава",
+        "Флайгон",
+        "Какния",
+        "Кактурн",
+        "Сваблу",
+        "Алтария",
+        "Зангус",
+        "Сивайпер",
+        "Лунатон",
+        "Солрок",
+        "Барбоа",
+        "Вискэш",
+        "Корфиш",
+        "Кродант",
+        "Балтой",
+        "Клэйдол",
+        "Лилип",
+        "Крэдили",
+        "Анорит",
+        "Армальдо",
+        "Фибас",
+        "Майлотик",
+        "Кастформ",
+        "Кеклеон",
+        "Шаппет",
+        "Бэнетт",
+        "Даскулл",
+        "Дасклопс",
+        "Тропиус",
+        "Чаймеко",
+        "Эбсол",
+        "Винаут",
+        "Снорант",
+        "Глэйли",
+        "Сфил",
+        "Силео",
+        "Уолрейн",
+        "Кламперл",
+        "Хантэйл",
+        "Горебисс",
+        "Реликант",
+        "Лювдиск",
+        "Багон",
+        "Шелгон",
+        "Саламенс",
+        "Белдум",
+        "Метанг",
+        "Метагросс",
+        "Реджирок",
+        "Реджайс",
+        "Реджистил",
+        "Латиас",
+        "Латиос",
+        "Кайогр",
+        "Граудон",
+        "Рэйкваза",
+        "Джирачи",
+        "Деоксис",
     ]
 }
